@@ -6,12 +6,13 @@
 
 package Config::OpenSSH::Authkey::Entry::Options;
 
+use 5.006000;
 use strict;
 use warnings;
 
 use Carp qw/croak/;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 # Delved from sshd(8), auth-options.c of OpenSSH 5.2. Insensitive match
 # required, as OpenSSH uses strncasecmp(3).
@@ -300,13 +301,13 @@ sshd(8), ssh-keygen(1), L<Config::OpenSSH::Authkey::Entry>
 
 =head1 AUTHOR
 
-Jeremy Mates, E<lt>jmates@cpan.orgE<gt>
+thrig - Jeremy Mates (cpan:JMATES) C<< <jmates at cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright 2010 by Jeremy Mates.
+Copyright 2010,2015 by Jeremy Mates.
 
-This program is free software; you can redistribute it and/or modify it
-under the Artistic license.
+This module is free software; you can redistribute it and/or modify it
+under the Artistic License (2.0).
 
 =cut
